import React, { ReactNode } from 'react';
import {
  ExtraColorsForMui5,
  selectColorPaletteConfig,
  useAppSelector,
} from '@graphpolaris/shared/data-access/store';
import { createTheme, ThemeProvider } from '@mui/material/styles';
import MapColorsConfigToMuiTheme from './mapColorsConfigToMuiTheme';

// Add custom theme variables to the mui theme types
declare module '@mui/material/styles' {
  interface Palette extends ExtraColorsForMui5 {} // eslint-disable-line
  interface Theme {
    palette: Palette;
  }
  interface PaletteOptions extends Partial<ExtraColorsForMui5> {} // eslint-disable-line
  interface ThemeOptions {
    palette?: PaletteOptions;
  }
}

export function OurThemeProvider({ children }: { children: ReactNode }) {
  const colorPaletteConfig = useAppSelector(selectColorPaletteConfig);

  // Create a new theme when our custom color palette in redux changed
  const theme = React.useMemo(
    () =>
      // Map our color palette config (stored in redux) to the mui 5 format
      createTheme(MapColorsConfigToMuiTheme(colorPaletteConfig)),
    [colorPaletteConfig]
  );

  return <ThemeProvider theme={theme}>{children}</ThemeProvider>;
}
export default OurThemeProvider;
